@@ -19,9 +19,9 @@ def gh_role(name, rawtext, text, lineno, inliner, options={}, content=[]):
         # direct link mode
         slug = text
     else:
-        slug = 'issues/' + text
-    text = '#' + text
-    ref = 'https://github.com/mne-tools/mne-bids/' + slug
+        slug = "issues/" + text
+    text = "#" + text
+    ref = "https://github.com/mne-tools/mne-bids/" + slug
     set_classes(options)
     node = reference(rawtext, text, refuri=ref, **options)
     return [node], []
@@ -29,5 +29,5 @@ def gh_role(name, rawtext, text, lineno, inliner, options={}, content=[]):
 
 def setup(app):
     """Do setup."""
-    app.add_role('gh', gh_role)
+    app.add_role("gh", gh_role)
     return
