@@ -49,8 +49,14 @@ import mne
 from mne.datasets import sample
 from mne import head_to_mri
 
-from mne_bids import (write_raw_bids, BIDSPath, write_anat, get_anat_landmarks,
-                      get_head_mri_trans, print_dir_tree)
+from mne_bids import (
+    write_raw_bids,
+    BIDSPath,
+    write_anat,
+    get_anat_landmarks,
+    get_head_mri_trans,
+    print_dir_tree,
+)
 
 # %%
 # We will be using the `MNE sample data <mne_sample_data_>`_ and write a basic
@@ -58,12 +64,18 @@ from mne_bids import (write_raw_bids, BIDSPath, write_anat, get_anat_landmarks,
 # :ref:`example <ex-convert-mne-sample>`.
 
 data_path = sample.data_path()
-event_id = {'Auditory/Left': 1, 'Auditory/Right': 2, 'Visual/Left': 3,
-            'Visual/Right': 4, 'Smiley': 5, 'Button': 32}
-raw_fname = op.join(data_path, 'MEG', 'sample', 'sample_audvis_raw.fif')
-events_fname = op.join(data_path, 'MEG', 'sample', 'sample_audvis_raw-eve.fif')
-output_path = op.abspath(op.join(data_path, '..', 'MNE-sample-data-bids'))
-fs_subjects_dir = op.join(data_path, 'subjects')  # FreeSurfer subjects dir
+event_id = {
+    "Auditory/Left": 1,
+    "Auditory/Right": 2,
+    "Visual/Left": 3,
+    "Visual/Right": 4,
+    "Smiley": 5,
+    "Button": 32,
+}
+raw_fname = op.join(data_path, "MEG", "sample", "sample_audvis_raw.fif")
+events_fname = op.join(data_path, "MEG", "sample", "sample_audvis_raw-eve.fif")
+output_path = op.abspath(op.join(data_path, "..", "MNE-sample-data-bids"))
+fs_subjects_dir = op.join(data_path, "subjects")  # FreeSurfer subjects dir
 
 # %%
 # To ensure the output path doesn't contain any leftover files from previous
@@ -79,16 +91,14 @@ if op.exists(output_path):
 # Read the input data and store it as BIDS data.
 
 raw = mne.io.read_raw_fif(raw_fname)
-raw.info['line_freq'] = 60  # specify power line frequency as required by BIDS
+raw.info["line_freq"] = 60  # specify power line frequency as required by BIDS
 
-sub = '01'
-ses = '01'
-task = 'audiovisual'
-run = '01'
-bids_path = BIDSPath(subject=sub, session=ses, task=task,
-                     run=run, root=output_path)
-write_raw_bids(raw, bids_path, events=events_fname,
-               event_id=event_id, overwrite=True)
+sub = "01"
+ses = "01"
+task = "audiovisual"
+run = "01"
+bids_path = BIDSPath(subject=sub, session=ses, task=task, run=run, root=output_path)
+write_raw_bids(raw, bids_path, events=events_fname, event_id=event_id, overwrite=True)
 
 # %%
 # Print the directory tree
@@ -104,11 +114,10 @@ print_dir_tree(output_path)
 # matrix :code:`trans`.
 
 # Get the path to our MRI scan
-t1_fname = op.join(fs_subjects_dir, 'sample', 'mri', 'T1.mgz')
+t1_fname = op.join(fs_subjects_dir, "sample", "mri", "T1.mgz")
 
 # Load the transformation matrix and show what it looks like
-trans_fname = op.join(data_path, 'MEG', 'sample',
-                      'sample_audvis_raw-trans.fif')
+trans_fname = op.join(data_path, "MEG", "sample", "sample_audvis_raw-trans.fif")
 trans = mne.read_trans(trans_fname)
 print(trans)
 
@@ -121,8 +130,7 @@ print(trans)
 # w.r.t. the T1 image.
 
 # First create the BIDSPath object.
-t1w_bids_path = BIDSPath(subject=sub, session=ses, root=output_path,
-                         suffix='T1w')
+t1w_bids_path = BIDSPath(subject=sub, session=ses, root=output_path, suffix="T1w")
 
 # use ``trans`` to transform landmarks from the ``raw`` file to
 # the voxel space of the image
@@ -130,7 +138,7 @@ landmarks = get_anat_landmarks(
     t1_fname,  # path to the MRI scan
     info=raw.info,  # the MEG data file info from the same subject as the MRI
     trans=trans,  # our transformation matrix
-    fs_subject='sample',  # FreeSurfer subject
+    fs_subject="sample",  # FreeSurfer subject
     fs_subjects_dir=fs_subjects_dir,  # FreeSurfer subjects directory
 )
 
@@ -139,7 +147,7 @@ t1w_bids_path = write_anat(
     image=t1_fname,  # path to the MRI scan
     bids_path=t1w_bids_path,
     landmarks=landmarks,  # the landmarks in MRI voxel space
-    verbose=True  # this will print out the sidecar file
+    verbose=True,  # this will print out the sidecar file
 )
 anat_dir = t1w_bids_path.directory
 
@@ -159,8 +167,9 @@ print_dir_tree(output_path)
 # .. note:: If this dataset were shared with you, you would first have to use
 #           the T1 image as input for the FreeSurfer recon-all, see
 #           :ref:`tut-freesurfer-mne`.
-estim_trans = get_head_mri_trans(bids_path=bids_path, fs_subject='sample',
-                                 fs_subjects_dir=fs_subjects_dir)
+estim_trans = get_head_mri_trans(
+    bids_path=bids_path, fs_subject="sample", fs_subjects_dir=fs_subjects_dir
+)
 
 # %%
 # Finally, let's use the T1 weighted MRI image and plot the anatomical
@@ -171,29 +180,32 @@ estim_trans = get_head_mri_trans(bids_path=bids_path, fs_subject='sample',
 # Get Landmarks from MEG file, 0, 1, and 2 correspond to LPA, NAS, RPA
 # and the 'r' key will provide us with the xyz coordinates. The coordinates
 # are expressed here in MEG Head coordinate system.
-pos = np.asarray((raw.info['dig'][0]['r'],
-                  raw.info['dig'][1]['r'],
-                  raw.info['dig'][2]['r']))
+pos = np.asarray(
+    (raw.info["dig"][0]["r"], raw.info["dig"][1]["r"], raw.info["dig"][2]["r"])
+)
 
 # We now use the ``head_to_mri`` function from MNE-Python to convert MEG
 # coordinates to MRI scanner RAS space. For the conversion we use our
 # estimated transformation matrix and the MEG coordinates extracted from the
 # raw file. `subjects` and `subjects_dir` are used internally, to point to
 # the T1-weighted MRI file: `t1_mgh_fname`. Coordinates are is mm.
-mri_pos = head_to_mri(pos=pos,
-                      subject='sample',
-                      mri_head_t=estim_trans,
-                      subjects_dir=fs_subjects_dir)
+mri_pos = head_to_mri(
+    pos=pos, subject="sample", mri_head_t=estim_trans, subjects_dir=fs_subjects_dir
+)
 
 # Our MRI written to BIDS, we got `anat_dir` from our `write_anat` function
-t1_nii_fname = op.join(anat_dir, 'sub-01_ses-01_T1w.nii.gz')
+t1_nii_fname = op.join(anat_dir, "sub-01_ses-01_T1w.nii.gz")
 
 # Plot it
-fig, axs = plt.subplots(3, 1, figsize=(7, 7), facecolor='k')
-for point_idx, label in enumerate(('LPA', 'NAS', 'RPA')):
-    plot_anat(t1_nii_fname, axes=axs[point_idx],
-              cut_coords=mri_pos[point_idx, :],
-              title=label, vmax=160)
+fig, axs = plt.subplots(3, 1, figsize=(7, 7), facecolor="k")
+for point_idx, label in enumerate(("LPA", "NAS", "RPA")):
+    plot_anat(
+        t1_nii_fname,
+        axes=axs[point_idx],
+        cut_coords=mri_pos[point_idx, :],
+        title=label,
+        vmax=160,
+    )
 plt.show()
 
 # %%
@@ -202,16 +214,11 @@ plt.show()
 #
 # We can write another types of MRI data such as FLASH images for BEM models
 
-flash_fname = op.join(fs_subjects_dir, 'sample', 'mri', 'flash', 'mef05.mgz')
+flash_fname = op.join(fs_subjects_dir, "sample", "mri", "flash", "mef05.mgz")
 
-flash_bids_path = \
-    BIDSPath(subject=sub, session=ses, root=output_path, suffix='FLASH')
+flash_bids_path = BIDSPath(subject=sub, session=ses, root=output_path, suffix="FLASH")
 
-write_anat(
-    image=flash_fname,
-    bids_path=flash_bids_path,
-    verbose=True
-)
+write_anat(image=flash_fname, bids_path=flash_bids_path, verbose=True)
 
 # %%
 # Writing defaced and anonymized T1 image
@@ -224,16 +231,16 @@ t1w_bids_path = write_anat(
     landmarks=landmarks,
     deface=True,
     overwrite=True,
-    verbose=True  # this will print out the sidecar file
+    verbose=True,  # this will print out the sidecar file
 )
 anat_dir = t1w_bids_path.directory
 
 # Our MRI written to BIDS, we got `anat_dir` from our `write_anat` function
-t1_nii_fname = op.join(anat_dir, 'sub-01_ses-01_T1w.nii.gz')
+t1_nii_fname = op.join(anat_dir, "sub-01_ses-01_T1w.nii.gz")
 
 # Plot it
 fig, ax = plt.subplots()
-plot_anat(t1_nii_fname, axes=ax, title='Defaced', vmax=160)
+plot_anat(t1_nii_fname, axes=ax, title="Defaced", vmax=160)
 plt.show()
 
 # %%
@@ -248,7 +255,7 @@ landmarks = get_anat_landmarks(
     flash_fname,  # path to the FLASH scan
     info=raw.info,  # the MEG data file info from the same subject as the MRI
     trans=trans,  # our transformation matrix
-    fs_subject='sample',  # freesurfer subject
+    fs_subject="sample",  # freesurfer subject
     fs_subjects_dir=fs_subjects_dir,  # freesurfer subjects directory
 )
 
@@ -258,15 +265,15 @@ flash_bids_path = write_anat(
     landmarks=landmarks,
     deface=True,
     overwrite=True,
-    verbose=True  # this will print out the sidecar file
+    verbose=True,  # this will print out the sidecar file
 )
 
 # Our MRI written to BIDS, we got `anat_dir` from our `write_anat` function
-flash_nii_fname = op.join(anat_dir, 'sub-01_ses-01_FLASH.nii.gz')
+flash_nii_fname = op.join(anat_dir, "sub-01_ses-01_FLASH.nii.gz")
 
 # Plot it
 fig, ax = plt.subplots()
-plot_anat(flash_nii_fname, axes=ax, title='Defaced', vmax=700)
+plot_anat(flash_nii_fname, axes=ax, title="Defaced", vmax=700)
 plt.show()
 
 # %%
@@ -280,16 +287,22 @@ plt.show()
 # .. note:: In FreeView, you need to use "RAS" and not "TkReg RAS" for this.
 #           You can also use voxel coordinates but, in FreeView, they
 #           are integers and so not as precise as the "RAS" decimal numbers.
-flash_ras_landmarks = \
-    np.array([[-74.53102838, 19.62854953, -52.2888194],
-              [-1.89454315, 103.69850925, 4.97120376],
-              [72.01200673, 21.09274883, -57.53678375]]) / 1e3  # mm -> m
+flash_ras_landmarks = (
+    np.array(
+        [
+            [-74.53102838, 19.62854953, -52.2888194],
+            [-1.89454315, 103.69850925, 4.97120376],
+            [72.01200673, 21.09274883, -57.53678375],
+        ]
+    )
+    / 1e3
+)  # mm -> m
 
 landmarks = mne.channels.make_dig_montage(
     lpa=flash_ras_landmarks[0],
     nasion=flash_ras_landmarks[1],
     rpa=flash_ras_landmarks[2],
-    coord_frame='ras'
+    coord_frame="ras",
 )
 
 flash_bids_path = write_anat(
@@ -298,12 +311,12 @@ flash_bids_path = write_anat(
     landmarks=landmarks,
     deface=True,
     overwrite=True,
-    verbose=True  # this will print out the sidecar file
+    verbose=True,  # this will print out the sidecar file
 )
 
 # Plot it
 fig, ax = plt.subplots()
-plot_anat(flash_nii_fname, axes=ax, title='Defaced', vmax=700)
+plot_anat(flash_nii_fname, axes=ax, title="Defaced", vmax=700)
 plt.show()
 
 # %%
