@@ -29,7 +29,7 @@ import pathlib
 import shutil
 
 import mne
-import mne_nirs  # For convenient downloading of example data
+from mne_nirs import datasets  # For convenient downloading of example data
 
 from mne_bids import write_raw_bids, BIDSPath, print_dir_tree
 from mne_bids.stats import count_events
@@ -44,7 +44,7 @@ from mne_bids.stats import count_events
 # We will use the MNE-NIRS package which includes convenient functions to
 # download openly available datasets.
 
-data_dir = pathlib.Path(mne_nirs.datasets.fnirs_motor_group.data_path())
+data_dir = pathlib.Path(datasets.fnirs_motor_group.data_path())
 
 # Let's see whether the data has been downloaded using a quick visualization
 # of the directory tree.
@@ -71,7 +71,7 @@ file_path = data_dir / "sub-01" / "nirs" / "sub-01_task-tapping_nirs.snirf"
 
 # Load the data
 raw = mne.io.read_raw_snirf(file_path, preload=False)
-raw.info['line_freq'] = 50  # specify power line frequency as required by BIDS
+raw.info["line_freq"] = 50  # specify power line frequency as required by BIDS
 
 # Sanity check, show the optode positions
 raw.plot_sensors()
@@ -80,9 +80,7 @@ raw.plot_sensors()
 # I also like to rename the annotations to something meaningful and
 # set the duration of each stimulus
 
-trigger_info = {'1.0': 'Control',
-                '2.0': 'Tapping/Left',
-                '3.0': 'Tapping/Right'}
+trigger_info = {"1.0": "Control", "2.0": "Tapping/Left", "3.0": "Tapping/Right"}
 raw.annotations.rename(trigger_info)
 raw.annotations.set_durations(5.0)
 
@@ -106,11 +104,11 @@ raw.annotations.set_durations(5.0)
 print(write_raw_bids.__doc__)
 
 # zero padding to account for >100 subjects in this dataset
-subject_id = '01'
+subject_id = "01"
 
 # define a task name and a directory where to save the data to
-task = 'Tapping'
-bids_root = data_dir.with_name(data_dir.name + '-bids')
+task = "Tapping"
+bids_root = data_dir.with_name(data_dir.name + "-bids")
 print(bids_root)
 
 # %%
@@ -173,8 +171,8 @@ counts
 #
 # If you are preparing a manuscript, please make sure to also cite MNE-BIDS
 # there.
-readme = op.join(bids_root, 'README')
-with open(readme, 'r', encoding='utf-8-sig') as fid:
+readme = op.join(bids_root, "README")
+with open(readme, "r", encoding="utf-8-sig") as fid:
     text = fid.read()
 print(text)
 
