@@ -39,7 +39,14 @@ import os.path as op
 import openneuro
 
 from mne.datasets import sample
-from mne_bids import BIDSPath, read_raw_bids, print_dir_tree, make_report
+from mne_bids import (
+    BIDSPath,
+    read_raw_bids,
+    print_dir_tree,
+    make_report,
+    find_matching_paths,
+    get_entity_vals,
+)
 
 # %%
 # Download a subject's data from an OpenNeuro BIDS dataset
@@ -56,16 +63,15 @@ from mne_bids import BIDSPath, read_raw_bids, print_dir_tree, make_report
 #          We're just using data from one subject to reduce the time
 #          it takes to run the example.
 
-dataset = 'ds002778'
-subject = 'pd6'
+dataset = "ds002778"
+subject = "pd6"
 
 # Download one subject's data from each dataset
 bids_root = op.join(op.dirname(sample.data_path()), dataset)
 if not op.isdir(bids_root):
     os.makedirs(bids_root)
 
-openneuro.download(dataset=dataset, target_dir=bids_root,
-                   include=[f'sub-{subject}'])
+openneuro.download(dataset=dataset, target_dir=bids_root, include=[f"sub-{subject}"])
 
 # %%
 # Explore the dataset contents
@@ -92,17 +98,25 @@ print(make_report(bids_root))
 # For now, we're interested only in the EEG data in the BIDS root directory
 # of the Parkinson's disease patient dataset. There were two sessions, one
 # where the patients took their regular anti-Parkinsonian medications and
-# one where they abstained for more than twelve hours. Let's start with the
-# off-medication session.
+# one where they abstained for more than twelve hours. For now, we are
+# not interested in the on-medication session.
 
-datatype = 'eeg'
-session = 'off'
-bids_path = BIDSPath(root=bids_root, session=session, datatype=datatype)
+sessions = get_entity_vals(bids_root, "session", ignore_sessions="on")
+datatype = "eeg"
+extensions = [".bdf", ".tsv"]  # ignore .json files
+bids_paths = find_matching_paths(
+    bids_root, datatypes=datatype, sessions=sessions, extensions=extensions
+)
 
 # %%
 # We can now retrieve a list of all MEG-related files in the dataset:
+print(bids_paths)
 
-print(bids_path.match())
+# %%
+# Note that this is the same as running:
+session = "off"
+bids_path = BIDSPath(root=bids_root, session=session, datatype=datatype)
+print(bids_path.match(ignore_json=True))
 
 # %%
 # The returned list contains ``BIDSpaths`` of 3 files:
@@ -124,11 +138,10 @@ print(bids_path.match())
 # our example, and ``'eeg'`` for EEG raw data. For MEG and EEG raw data, the
 # suffix is identical to the datatype, so don't let yourself be confused here!
 
-task = 'rest'
-suffix = 'eeg'
+task = "rest"
+suffix = "eeg"
 
-bids_path = BIDSPath(subject=subject, session=session, task=task,
-                     suffix=suffix, datatype=datatype, root=bids_root)
+bids_path = bids_path.update(subject=subject, task=task, suffix=suffix)
 
 # %%
 # Now let's print the contents of ``bids_path``.
@@ -183,17 +196,17 @@ raw = read_raw_bids(bids_path=bids_path, verbose=False)
 #
 # Basic subject metadata is here.
 
-print(raw.info['subject_info'])
+print(raw.info["subject_info"])
 
 # %%
 # Power line frequency is here.
 
-print(raw.info['line_freq'])
+print(raw.info["line_freq"])
 
 # %%
 # Sampling frequency is here.
 
-print(raw.info['sfreq'])
+print(raw.info["sfreq"])
 
 # %%
 # Events are now Annotations
