@@ -17,10 +17,10 @@ from mne.utils import run_subprocess
 @pytest.fixture(scope="session")
 def _bids_validate():
     """Fixture to run BIDS validator."""
-    vadlidator_args = ['--config.error=41']
-    exe = os.getenv('VALIDATOR_EXECUTABLE', 'bids-validator')
+    vadlidator_args = ["--config.error=41"]
+    exe = os.getenv("VALIDATOR_EXECUTABLE", "bids-validator")
 
-    if platform.system() == 'Windows':
+    if platform.system() == "Windows":
         shell = True
     else:
         shell = False
